import { DataSourceType } from '../transformer-context/transformer-datasource-provider';
export type ModelDataSourceStrategy = DefaultDynamoDbModelDataSourceStrategy | AmplifyDynamoDbModelDataSourceStrategy | SQLLambdaModelDataSourceStrategy;
export interface ModelDataSourceStrategyBase {
    dbType: ModelDataSourceStrategyDbType;
}
export type ModelDataSourceStrategyDbType = 'DYNAMODB' | 'MYSQL' | 'POSTGRES';
export interface DefaultDynamoDbModelDataSourceStrategy extends ModelDataSourceStrategyBase {
    readonly dbType: 'DYNAMODB';
    readonly provisionStrategy: 'DEFAULT';
}
export interface AmplifyDynamoDbModelDataSourceStrategy extends ModelDataSourceStrategyBase {
    readonly dbType: 'DYNAMODB';
    readonly provisionStrategy: 'AMPLIFY_TABLE';
}
export interface SQLLambdaModelDataSourceStrategy extends ModelDataSourceStrategyBase {
    readonly name: string;
    readonly dbType: 'MYSQL' | 'POSTGRES';
    readonly dbConnectionConfig: SqlModelDataSourceDbConnectionConfig;
    readonly vpcConfiguration?: VpcConfig;
    readonly customSqlStatements?: Record<string, string>;
    readonly sqlLambdaProvisionedConcurrencyConfig?: ProvisionedConcurrencyConfig;
}
export interface VpcConfig {
    readonly vpcId: string;
    readonly securityGroupIds: string[];
    readonly subnetAvailabilityZoneConfig: SubnetAvailabilityZone[];
}
export interface ProvisionedConcurrencyConfig {
    readonly provisionedConcurrentExecutions: number;
}
export interface SubnetAvailabilityZone {
    readonly subnetId: string;
    readonly availabilityZone: string;
}
export interface SqlModelDataSourceDbConnectionConfig {
    readonly hostnameSsmPath: string;
    readonly portSsmPath: string;
    readonly usernameSsmPath: string;
    readonly passwordSsmPath: string;
    readonly databaseNameSsmPath: string;
}
export interface CustomSqlDataSourceStrategy {
    readonly typeName: 'Query' | 'Mutation';
    readonly fieldName: string;
    readonly dataSourceType: DataSourceType;
}
export interface DataSourceStrategiesProvider {
    customSqlDataSourceStrategies: CustomSqlDataSourceStrategy[];
}
export interface RDSLayerMapping {
    readonly [key: string]: {
        layerRegion: string;
    };
}
//# sourceMappingURL=types.d.ts.map